package com.caimei.module.pay.dao;

import com.caimei.module.base.entity.po.SeconHandProduct;
import com.caimei.module.base.entity.vo.*;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

import java.math.BigDecimal;
import java.util.List;

/**
 * Description
 *
 * @author : plf
 * @date : 2020/5/9
 */
@Mapper
public interface PayDao {
    OrderVo findOrder(Integer orderId);

    List<DiscernReceiptVo> getDiscernReceipt(OrderVo order);

    void updateSelective(OrderVo order);

    void insertDiscernReceipt(DiscernReceiptVo discernReceipt);

    void insertOrderRelation(OrderRelationVo relation);

    OrderPayLinkVo findOrderPayLink(@Param("orderId") Long orderId, @Param("amount") BigDecimal amount);

    void updateOrderPayLink(OrderPayLinkVo orderPayLink);

    void insertOrderPayLink(OrderPayLinkVo orderPayLink);

    OrderPayLinkVo getOrderPayLink(String linkLogo);

    UserVo findUser(Long userID);

    List<OrderProductVo> fandAllOrderProduct(Integer orderId);

    void updateSeconHand(SeconHandProduct seconHandProduct);

    void insertSplitAccount(SplitAccountVo splitAccount);

    void updateSplitAccountByPay(String mbOrderId);

    /**
     * 修改用户余额
     *
     * @param userMoney
     * @param ableUserMoney
     * @param userId
     */
    void updateUserMoney(@Param("userMoney") BigDecimal userMoney, @Param("ableUserMoney") BigDecimal ableUserMoney, @Param("userId") Integer userId);

    /**
     * 新增余额收支记录
     *
     * @param balanceRecord
     */
    void insertBalanceRecord(BalanceRecordVo balanceRecord);

    /**
     * 获取线上支付开关状态
     */
    Integer getPayOnLineSwitch();

    /**
     * 查询子商户商编
     *
     * @param shopId
     * @return
     */
    String findCommercialCode(Long shopId);

    /**
     * 查询已支付金额
     *
     * @param orderProductId
     * @return
     */
    BigDecimal findPaidAmount(Integer orderProductId);

    /**
     * 查询子订单
     *
     * @param orderId
     * @return
     */
    List<ShopOrderVo> findShopOrder(Long orderId);

    /**
     * 查询已支付运费
     *
     * @param orderId
     * @param shopId
     * @return
     */
    BigDecimal findShipping(@Param("orderId") Long orderId, @Param("shopId") Integer shopId);

    /**
     * 查询未分账已支付收款
     *
     * @param currentTime 延迟时间
     * @return
     */
    List<OrderRelationVo> findUnallocatedAccount(String currentTime);

    /**
     * 查询分账给子商户号
     *
     * @param mbOrderId 米花平台交易流水号
     * @return
     */
    List<SplitAccountVo> findByMbOrderId(String mbOrderId);

    /**
     * 查询已付供应商金额
     *
     * @param shopOrderId
     * @return
     */
    BigDecimal findPaidShop(Integer shopOrderId);

    /**
     * 保存付款单
     *
     * @param payShop
     */
    void insertPayShop(PayShopVo payShop);

    /**
     * 保存付款记录
     *
     * @param shopRecord
     */
    void insertPayShopRecord(PayShopRecordVo shopRecord);

    /**
     * 修改收款分账状态
     *
     * @param mbOrderId
     */
    void updateBySplitStatus(String mbOrderId);

    /**
     * 修改子订单付款状态及付款金额
     *
     * @param shopOrderId 子订单id
     * @param paidShop    已支付金额
     * @param payStatus   付款状态
     */
    void updateShopOrderByPayStatus(@Param("shopOrderId") Integer shopOrderId, @Param("paidShop") BigDecimal paidShop, @Param("payStatus") String payStatus);

    /**
     * 修改主订单付款状态
     *
     * @param orderId
     * @param payStatus
     */
    void updateOrderByPayStatus(@Param("orderId") Integer orderId, @Param("payStatus") String payStatus);
}
